leap.mail
=========
Mail services for the LEAP Client.

.. image:: https://pypip.in/v/leap.mail/badge.png
        :target: https://crate.io/packages/leap.mail


More info: https://leap.se

running tests
-------------

* nosetests --with-progressive leap.mail.imap.test_imap
* trial leap.mail.smtp
